<?xml version="1.0" encoding="utf-8"?>

<!-- Original German translation done by Frank Tegtmeyer -->

<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>ColorParameter</name>
    <message>
        <location filename="../src/FilterParameters/ColorParameter.cpp" line="168"/>
        <source>Select color</source>
        <translation>Farb-Auswahl</translation>
    </message>
</context>
<context>
    <name>DialogSettings</name>
    <message>
        <location filename="../ui/dialogsettings.ui" line="14"/>
        <source>Dialog</source>
        <translatorcomment>not sure about the use</translatorcomment>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="221"/>
        <source>Internet updates</source>
        <translation>Aktualisierungen über Internet</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="230"/>
        <source>Update now</source>
        <translation>Jetzt aktualisieren</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="30"/>
        <source>Layout</source>
        <translation>Anordnung</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="24"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="64"/>
        <source>Preview on the &amp;left</source>
        <translation>Vorschau auf &amp;linker Seite</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="94"/>
        <source>Pre&amp;view on right side</source>
        <translation>Vorschau auf &amp;rechter Seite</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="113"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="119"/>
        <source>&amp;Default</source>
        <translation>&amp;Standard</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="126"/>
        <source>Dar&amp;k</source>
        <translation>&amp;Dunkel</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="139"/>
        <source>&lt;i&gt;(Restart needed)&lt;/I&gt;</source>
        <translation>&lt;i&gt;(Neustart erforderlich)&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="149"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="179"/>
        <source>Always enable preview zooming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="186"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;(Warning: preview may be inaccurate&lt;br/&gt;if checked.)&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="215"/>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="253"/>
        <location filename="../src/DialogSettings.cpp" line="84"/>
        <source>Output messages</source>
        <translation>Ausgabe der Meldungen</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="196"/>
        <source>Dialogs</source>
        <translatorcomment>not sure about the use</translatorcomment>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="202"/>
        <source>Use native color dialog</source>
        <translation>System-Farbwähler verwenden</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="163"/>
        <source>Preview</source>
        <translation type="unfinished">Vorschau</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="169"/>
        <source>Timeout (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="36"/>
        <source>Show institution logos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="262"/>
        <source>Notify when scheduled update fails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="304"/>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="64"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="70"/>
        <source>Never</source>
        <translation>Niemals</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="71"/>
        <source>Daily</source>
        <translation>Täglich</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="72"/>
        <source>Weekly</source>
        <translation>Wöchentlich</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="73"/>
        <source>Every 2 weeks</source>
        <translation>Alle zwei Wochen</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="74"/>
        <source>Monthly</source>
        <translation>Monatlich</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="76"/>
        <source>At launch (debug)</source>
        <translation>Beim Starten (Debug)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="85"/>
        <source>Quiet (default)</source>
        <translation>Keine Ausgabe (Standard)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="86"/>
        <source>Verbose (console)</source>
        <translation>Ausführlich (Konsole)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="87"/>
        <source>Verbose (log file)</source>
        <translation>Ausführlich (Log-Datei)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="88"/>
        <source>Very verbose (console)</source>
        <translation>Sehr ausführlich (Konsole)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="89"/>
        <source>Very verbose (log file)</source>
        <translation>Sehr ausführlich (Log-Datei)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="90"/>
        <source>Debug (console)</source>
        <translation>Debuggen (Konsole)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="91"/>
        <source>Debug (log file)</source>
        <translation>Debuggen (Log-Datei)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="107"/>
        <source>Check to use Native/OS color dialog, uncheck to use Qt&apos;s</source>
        <translation>Auswählen, um System-Farbwähler zu nutzen, aus für Qt-Farbwähler</translation>
    </message>
</context>
<context>
    <name>FileParameter</name>
    <message>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="149"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="152"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="155"/>
        <source>Select a file</source>
        <translation>Datei auswählen</translation>
    </message>
</context>
<context>
    <name>FilterParametersWidget</name>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="39"/>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="172"/>
        <source>&lt;i&gt;Select a filter&lt;/i&gt;</source>
        <translation type="unfinished">&lt;i&gt;Filter auswählen&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="139"/>
        <source>&lt;i&gt;No parameters&lt;/i&gt;</source>
        <translation type="unfinished">&lt;i&gt;Keine Parameter anzugeben&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="144"/>
        <source>Error parsing filter parameters

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FiltersPresenter</name>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="339"/>
        <source>Unknown filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="427"/>
        <source>Cannot find this fave&apos;s original filter
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FiltersView</name>
    <message>
        <location filename="../ui/filtersview.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished">GMIC</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="65"/>
        <source>Rename fave</source>
        <translation type="unfinished">Favorit umbenennen</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="67"/>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="344"/>
        <source>Remove fave</source>
        <translation type="unfinished">Kein Favorit mehr</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="69"/>
        <source>Clone fave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="73"/>
        <source>Add fave</source>
        <translation type="unfinished">Als Favorit merken</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="345"/>
        <source>Do you really want to remove the following fave?

%1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FolderParameter</name>
    <message>
        <location filename="../src/FilterParameters/FolderParameter.cpp" line="127"/>
        <source>Select a folder</source>
        <translation>Ordner wählen</translation>
    </message>
</context>
<context>
    <name>HeadlessProgressDialog</name>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="14"/>
        <source>Dialog</source>
        <translatorcomment>guessed from french translation</translatorcomment>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="68"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>InOutPanel</name>
    <message>
        <location filename="../ui/inoutpanel.ui" line="40"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="271"/>
        <source>Input / Output</source>
        <translation>Quellen und Ziel</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="47"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="102"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="72"/>
        <source>Input layers</source>
        <translation>Ursprungs-Ebenen</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="138"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="95"/>
        <source>Output mode</source>
        <translation>Ziel</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="125"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="111"/>
        <source>Preview mode</source>
        <translation>Vorschau-Modus</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="273"/>
        <source>Input / Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="273"/>
        <source>Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="275"/>
        <source>Output / Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="275"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageSelectionWidget</name>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished">GMIC</translation>
    </message>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="38"/>
        <source>&lt;i&gt;(Restart needed)&lt;/i&gt;</source>
        <translation>&lt;i&gt;(Neustart erforderlich)&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/Widgets/LanguageSelectionWidget.cpp" line="48"/>
        <source>System default (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="161"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Download filter definitions from remote sources&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter-Definitionen von externen Quellen laden&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="164"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="128"/>
        <source>Selection mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="496"/>
        <source>TextLabel</source>
        <translatorcomment>why empty?</translatorcomment>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="233"/>
        <location filename="../ui/mainwindow.ui" line="240"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="386"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enable/disable preview&lt;br/&gt;(Ctrl+P)&lt;br/&gt;(right click on preview image for instant swapping)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="389"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="480"/>
        <source>Settings...</source>
        <translation>Einstellungen...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="509"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbruch</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="522"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Vollbild</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="535"/>
        <source>&amp;Apply</source>
        <translation>&amp;Anwenden</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="548"/>
        <source>&amp;OK</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="102"/>
        <source>Add fave</source>
        <translation>Als Favorit merken</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="104"/>
        <source>Reset parameters to default values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="110"/>
        <source>Copy G&apos;MIC command to clipboard</source>
        <translation>G&apos;MIC-Befehl in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="166"/>
        <source>Update filters</source>
        <translation>Filter aktualisieren</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="113"/>
        <source>Rename fave</source>
        <translation>Favorit umbenennen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="115"/>
        <source>Remove fave</source>
        <translation>Kein Favorit mehr</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="119"/>
        <source>Expand/Collapse all</source>
        <translation>Alles aufklappen/einklappen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="121"/>
        <source>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandy University (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</source>
        <translation>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandie Université (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="329"/>
        <source>Update completed</source>
        <translation>Aktualisierung ist durchgeführt</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="329"/>
        <location filename="../src/MainWindow.cpp" line="331"/>
        <location filename="../src/MainWindow.cpp" line="385"/>
        <source>Filter definitions have been updated.</source>
        <translation>Die Filter-Definitionen wurden aktualisiert.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="334"/>
        <source>No download was needed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="381"/>
        <source>Filters update could not be achieved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="503"/>
        <source>The update could not be achieved&lt;br&gt;because of the following errors:&lt;br&gt;</source>
        <translation>Wegen der folgenden Fehler konnte&lt;br/&gt;die Aktualisierung nicht durchgeführt werden:&lt;br/&gt;</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="509"/>
        <source>Update error</source>
        <translation>Fehler bei der Aktualisierung</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="711"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="807"/>
        <source>Waiting for cancelled jobs...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1169"/>
        <source>Import faves</source>
        <translation>Favoriten importieren</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1169"/>
        <source>Do you want to import faves from file below?&lt;br/&gt;%1</source>
        <translation>Möchten Sie Favoriten aus dieser Datei importieren?&lt;br/&gt;%1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1172"/>
        <source>Don&apos;t ask again</source>
        <translation>Nicht mehr fragen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1284"/>
        <source>Confirmation</source>
        <translation>Bestätigung</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1284"/>
        <source>A gmic command is running.&lt;br&gt;Do you really want to close the plugin?</source>
        <translation>Ein GMIC-Kommando ist aktiv.&lt;br&gt;Wollen Sie das Plugin wirklich schließen?</translation>
    </message>
</context>
<context>
    <name>MultilineTextParameterWidget</name>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="29"/>
        <source>Update</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/MultilineTextParameterWidget.cpp" line="38"/>
        <source>Ctrl+Return</source>
        <translation>Strg+Enter</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWidget</name>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="48"/>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="49"/>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="55"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="46"/>
        <source>G&apos;MIC-Qt Plug-in progression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="147"/>
        <source>Updating filters...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="202"/>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="215"/>
        <source>[Processing %1 | %2]</source>
        <translation>[Berechne %1 | %2]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="217"/>
        <source>[Processing %1]</source>
        <translation>[Berechne %1]</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWindow</name>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="30"/>
        <location filename="../ui/progressinfowindow.ui" line="50"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="72"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="138"/>
        <source>%1 seconds</source>
        <translation>%1 Sekunden</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="148"/>
        <source>[Processing %1 | %2]</source>
        <translation>|Berechne %1 | %2]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="150"/>
        <source>[Processing %1]</source>
        <translation>|Berechne %1]</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="68"/>
        <source>Select an image to open...</source>
        <translation>Bild zum Laden auswählen...</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="68"/>
        <source>PNG &amp; JPG files (*.png *.jpeg *.jpg *.PNG *.JPEG *.JPG)</source>
        <translation>PNG- &amp; JPG-Dateien (*.png *.jpeg *.jpg *.PNG *.JPEG *.JPG)</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="74"/>
        <source>Error</source>
        <translation type="unfinished">Fehler</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="74"/>
        <source>Could not open file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="78"/>
        <source>Default image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="88"/>
        <source>Visible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="86"/>
        <source>Available filters (%1)</source>
        <translation>Verfügbare Filter (%1)</translation>
    </message>
</context>
<context>
    <name>SearchFieldWidget</name>
    <message>
        <location filename="../ui/SearchFieldWidget.ui" line="20"/>
        <source>Frame</source>
        <translation>Frame</translation>
    </message>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="76"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="77"/>
        <source>Search in filters list (%1)</source>
        <translation>In Filter-Liste suchen (%1)</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <location filename="../src/Updater.cpp" line="204"/>
        <source>Could not read/decompress %1</source>
        <translation>%1 ist nicht lesbar oder kann nicht entpackt werden</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="195"/>
        <source>Error downloading %1 (empty file?)</source>
        <translation>Fehler beim Laden von %1 (Leere Datei?)</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="210"/>
        <source>Error creating file %1</source>
        <translation>Fehler beim Erzeugen der Datei %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="214"/>
        <source>Error writing file %1</source>
        <translation>Fehler beim Schreiben der Datei %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="231"/>
        <source>Error downloading %1&lt;br/&gt;Error %2: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="264"/>
        <source>Download timeout: %1</source>
        <translation>Zeitüberschreitung beim Herunterladen : %1</translation>
    </message>
</context>
<context>
    <name>ZoomLevelSelector</name>
    <message>
        <location filename="../ui/zoomlevelselector.ui" line="20"/>
        <source>Form</source>
        <translation type="unfinished">GMIC</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="51"/>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="52"/>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="53"/>
        <source>Reset zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="153"/>
        <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
